@@ -12,10 +12,10 @@ Welcome to { TITLE }
 """
 
 
-def commands(commands: list):
+def commands(items: list):
     """Collect (Click) Commands"""
     command_sources = [cli]
-    for active in commands:
+    for active in items:
         if isinstance(active.object, click.core.Group):
             command_sources.append(active.object)
     return click.CommandCollection(name=TITLE, help=HELP_TEXT, sources=command_sources)
