@@ -5,14 +5,13 @@ from typing_extensions import TypedDict
 
 from graphql.error.graphql_error import format_error as format_graphql_error
 
-from strawberry.exceptions import MissingQueryError
 from strawberry.types import ExecutionResult
 
 
 class GraphQLHTTPResponse(TypedDict, total=False):
-    data: Optional[Dict[str, Any]]
-    errors: Optional[List[Any]]
-    extensions: Optional[Dict[str, Any]]
+    data: Optional[Dict[str, object]]
+    errors: Optional[List[object]]
+    extensions: Optional[Dict[str, object]]
 
 
 def process_result(result: ExecutionResult) -> GraphQLHTTPResponse:
@@ -28,7 +27,9 @@ def process_result(result: ExecutionResult) -> GraphQLHTTPResponse:
 
 @dataclass
 class GraphQLRequestData:
-    query: str
+    # query is optional here as it can be added by an extensions
+    # (for example an extension for persisted queries)
+    query: Optional[str]
     variables: Optional[Dict[str, Any]]
     operation_name: Optional[str]
 
@@ -41,13 +42,8 @@ def parse_query_params(params: Dict[str, str]) -> Dict[str, Any]:
 
 
 def parse_request_data(data: Mapping[str, Any]) -> GraphQLRequestData:
-    if "query" not in data:
-        raise MissingQueryError()
-
-    result = GraphQLRequestData(
-        query=data["query"],
+    return GraphQLRequestData(
+        query=data.get("query"),
         variables=data.get("variables"),
         operation_name=data.get("operationName"),
     )
-
-    return result
